==> axis2-1.8.2-src.zip: axis2-1.8.2/modules/jaxws-integration/src/test/java/org/apache/axis2/jaxws/sample/doclitbarenoarg/DocLitBareNoArgPortTypeImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *      
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axis2.jaxws.sample.doclitbarenoarg;

import org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType;

import javax.jws.WebService;

@WebService(serviceName="BareDocLitNoArgService", 
            endpointInterface="org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType")
public class DocLitBareNoArgPortTypeImpl implements DocLitBareNoArgPortType {

    /* (non-Javadoc)
     * @see org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType#twoWayEmpty()
     */
    public String twoWayEmpty() {
        return "org.apache.axis2.jaxws.sample.doclitbarenoarg.DocLitBareNoArgPortTypeImpl.twoWayEmpty";
    }

}

==> axis2-2.0.0-src.zip: axis2-2.0.0/modules/jaxws-integration/src/test/java/org/apache/axis2/jaxws/sample/doclitbarenoarg/DocLitBareNoArgPortTypeImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *      
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axis2.jaxws.sample.doclitbarenoarg;

import org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType;

import jakarta.jws.WebService;

@WebService(serviceName="BareDocLitNoArgService", 
            endpointInterface="org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType")
public class DocLitBareNoArgPortTypeImpl implements DocLitBareNoArgPortType {

    /* (non-Javadoc)
     * @see org.apache.axis2.jaxws.sample.doclitbarenoarg.sei.DocLitBareNoArgPortType#twoWayEmpty()
     */
    public String twoWayEmpty() {
        return "org.apache.axis2.jaxws.sample.doclitbarenoarg.DocLitBareNoArgPortTypeImpl.twoWayEmpty";
    }

}
